@@ -1,9 +1,14 @@
+try:
+    from importlib.metadata import version
+except ModuleNotFoundError:
+    from importlib_metadata import version
+
+
 from ploomber_core.telemetry.telemetry import Telemetry
-from ploomber_engine import __version__
 
 
 telemetry = Telemetry(
     api_key="phc_P9SpSeypyPwxrMdFn2edOOEooQioF2axppyEeDwtMSP",
     package_name="ploomber-engine",
-    version=__version__,
+    version=version("ploomber-engine"),
 )
