@@ -162,9 +162,7 @@ def _parse_cli_parameters(parameters):
 
 
 @telemetry.log_call("track-execution")
-def track_execution(
-    filename, parameters=None, database="experiments.db", quiet=False
-):
+def track_execution(filename, parameters=None, database="experiments.db", quiet=False):
     """
     Execute a script or notebook and write outputs to a SQLite database
     """
